==> data-hub-4.2.5-sources.jar: io/intino/datahub/graph/Component.java <==
package io.intino.datahub.graph;

import io.intino.datahub.graph.*;

public class Component  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
	protected boolean multiple;
	protected java.util.List<io.intino.datahub.graph.Attribute> attributeList = new java.util.ArrayList<>();
	protected java.util.List<io.intino.datahub.graph.Component> componentList = new java.util.ArrayList<>();
	protected java.util.List<io.intino.datahub.graph.Component.Has> hasList = new java.util.ArrayList<>();
	protected io.intino.datahub.graph.Component.ExtensionOf _extensionOf;

	public Component(io.intino.magritte.framework.Node node) {
		super(node);
	}

	public boolean multiple() {
		return multiple;
	}

	public Component multiple(boolean value) {
		this.multiple = value;
		return (Component) this;
	}

	public java.util.List<io.intino.datahub.graph.Attribute> attributeList() {
		return java.util.Collections.unmodifiableList(attributeList);
	}

	public io.intino.datahub.graph.Attribute attribute(int index) {
		return attributeList.get(index);
	}

	public java.util.List<io.intino.datahub.graph.Attribute> attributeList(java.util.function.Predicate<io.intino.datahub.graph.Attribute> predicate) {
		return attributeList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}

	public java.util.List<io.intino.datahub.graph.Component> componentList() {
		return java.util.Collections.unmodifiableList(componentList);
	}

	public io.intino.datahub.graph.Component component(int index) {
		return componentList.get(index);
	}

	public java.util.List<io.intino.datahub.graph.Component> componentList(java.util.function.Predicate<io.intino.datahub.graph.Component> predicate) {
		return componentList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}

	public java.util.List<io.intino.datahub.graph.Component.Has> hasList() {
		return java.util.Collections.unmodifiableList(hasList);
	}

	public io.intino.datahub.graph.Component.Has has(int index) {
		return hasList.get(index);
	}

	public java.util.List<io.intino.datahub.graph.Component.Has> hasList(java.util.function.Predicate<io.intino.datahub.graph.Component.Has> predicate) {
		return hasList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}

	public io.intino.datahub.graph.Component.ExtensionOf asExtensionOf() {
		return a$(io.intino.datahub.graph.Component.ExtensionOf.class);
	}

	public io.intino.datahub.graph.Component.ExtensionOf asExtensionOf(io.intino.datahub.graph.Component parent) {
		io.intino.datahub.graph.Component.ExtensionOf newElement = core$().addAspect(io.intino.datahub.graph.Component.ExtensionOf.class);
		newElement.core$().set(newElement, "parent", java.util.Collections.singletonList(parent));
	    return newElement;
	}

	public boolean isExtensionOf() {
		return core$().is(io.intino.datahub.graph.Component.ExtensionOf.class);
	}

	public void removeExtensionOf() {
		core$().removeAspect(io.intino.datahub.graph.Component.ExtensionOf.class);
	}

	protected java.util.List<io.intino.magritte.framework.Node> componentList$() {
		java.util.Set<io.intino.magritte.framework.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(attributeList).forEach(c -> components.add(c.core$()));
		new java.util.ArrayList<>(componentList).forEach(c -> components.add(c.core$()));
		new java.util.ArrayList<>(hasList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
		map.put("multiple", new java.util.ArrayList(java.util.Collections.singletonList(this.multiple)));
		return map;
	}

	@Override
	protected void addNode$(io.intino.magritte.framework.Node node) {
		super.addNode$(node);
		if (node.is("Attribute")) this.attributeList.add(node.as(io.intino.datahub.graph.Attribute.class));
		if (node.is("Component")) this.componentList.add(node.as(io.intino.datahub.graph.Component.class));
		if (node.is("Component$Has")) this.hasList.add(node.as(io.intino.datahub.graph.Component.Has.class));
	}

	@Override
	    protected void removeNode$(io.intino.magritte.framework.Node node) {
	        super.removeNode$(node);
	        if (node.is("Attribute")) this.attributeList.remove(node.as(io.intino.datahub.graph.Attribute.class));
	        if (node.is("Component")) this.componentList.remove(node.as(io.intino.datahub.graph.Component.class));
	        if (node.is("Component$Has")) this.hasList.remove(node.as(io.intino.datahub.graph.Component.Has.class));
	    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
		if (name.equalsIgnoreCase("multiple")) this.multiple = io.intino.magritte.framework.loaders.BooleanLoader.load(values, this).get(0);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
		if (name.equalsIgnoreCase("multiple")) this.multiple = (java.lang.Boolean) values.get(0);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}

		public io.intino.datahub.graph.Attribute attribute() {
		    io.intino.datahub.graph.Attribute newElement = core$().graph().concept(io.intino.datahub.graph.Attribute.class).createNode(this.name, core$()).as(io.intino.datahub.graph.Attribute.class);

		    return newElement;
		}

		public io.intino.datahub.graph.Component component() {
		    io.intino.datahub.graph.Component newElement = core$().graph().concept(io.intino.datahub.graph.Component.class).createNode(this.name, core$()).as(io.intino.datahub.graph.Component.class);

		    return newElement;
		}

		public io.intino.datahub.graph.Component.Has has(io.intino.datahub.graph.Component element) {
		    io.intino.datahub.graph.Component.Has newElement = core$().graph().concept(io.intino.datahub.graph.Component.Has.class).createNode(this.name, core$()).as(io.intino.datahub.graph.Component.Has.class);
			newElement.core$().set(newElement, "element", java.util.Collections.singletonList(element));
		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void attribute(java.util.function.Predicate<io.intino.datahub.graph.Attribute> filter) {
			new java.util.ArrayList<>(attributeList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
		}

		public void component(java.util.function.Predicate<io.intino.datahub.graph.Component> filter) {
			new java.util.ArrayList<>(componentList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
		}

		public void has(java.util.function.Predicate<io.intino.datahub.graph.Component.Has> filter) {
			new java.util.ArrayList<>(hasList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
		}
	}

	public static class Has  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
		protected io.intino.datahub.graph.Component element;
		protected boolean multiple;

		public Has(io.intino.magritte.framework.Node node) {
			super(node);
		}

		public io.intino.datahub.graph.Component element() {
			return element;
		}

		public boolean multiple() {
			return multiple;
		}

		public Has element(io.intino.datahub.graph.Component value) {
			this.element = value;
			return (Has) this;
		}

		public Has multiple(boolean value) {
			this.multiple = value;
			return (Has) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("element", this.element != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.element)) : java.util.Collections.emptyList());
			map.put("multiple", new java.util.ArrayList(java.util.Collections.singletonList(this.multiple)));
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("element")) this.element = io.intino.magritte.framework.loaders.NodeLoader.load(values, io.intino.datahub.graph.Component.class, this).get(0);
			else if (name.equalsIgnoreCase("multiple")) this.multiple = io.intino.magritte.framework.loaders.BooleanLoader.load(values, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("element")) this.element = values.get(0)!= null ? core$().graph().load(((io.intino.magritte.framework.Layer) values.get(0)).core$().id()).as(io.intino.datahub.graph.Component.class) : null;
			else if (name.equalsIgnoreCase("multiple")) this.multiple = (java.lang.Boolean) values.get(0);
		}

		public io.intino.datahub.graph.NessGraph graph() {
			return (io.intino.datahub.graph.NessGraph) core$().graph().as(io.intino.datahub.graph.NessGraph.class);
		}
	}

	public static class ExtensionOf  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
		protected io.intino.datahub.graph.Component parent;
		protected io.intino.datahub.graph.Component _component;

		public ExtensionOf(io.intino.magritte.framework.Node node) {
			super(node);
		}

		public io.intino.datahub.graph.Component parent() {
			return parent;
		}

		public boolean multiple() {
			return _component.multiple();
		}

		public ExtensionOf parent(io.intino.datahub.graph.Component value) {
			this.parent = value;
			return (ExtensionOf) this;
		}

		public ExtensionOf multiple(boolean value) {
			this._component.multiple(value);
			return (ExtensionOf) this;
		}

		public java.util.List<io.intino.datahub.graph.Attribute> attributeList() {
			return (java.util.List<io.intino.datahub.graph.Attribute>) _component.attributeList();
		}

		public io.intino.datahub.graph.Attribute attributeList(int index) {
			return _component.attributeList().get(index);
		}

		public java.util.List<io.intino.datahub.graph.Component> componentList() {
			return (java.util.List<io.intino.datahub.graph.Component>) _component.componentList();
		}

		public io.intino.datahub.graph.Component componentList(int index) {
			return _component.componentList().get(index);
		}

		public java.util.List<io.intino.datahub.graph.Component.Has> hasList() {
			return (java.util.List<io.intino.datahub.graph.Component.Has>) _component.hasList();
		}

		public io.intino.datahub.graph.Component.Has hasList(int index) {
			return _component.hasList().get(index);
		}
		public io.intino.datahub.graph.Component asComponent() {
			return (io.intino.datahub.graph.Component) a$(io.intino.datahub.graph.Component.class);
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("parent", this.parent != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.parent)) : java.util.Collections.emptyList());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("parent")) this.parent = io.intino.magritte.framework.loaders.NodeLoader.load(values, io.intino.datahub.graph.Component.class, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("parent")) this.parent = values.get(0)!= null ? core$().graph().load(((io.intino.magritte.framework.Layer) values.get(0)).core$().id()).as(io.intino.datahub.graph.Component.class) : null;
		}

		@Override
		protected void sync$(io.intino.magritte.framework.Layer layer) {
			super.sync$(layer);
		    if (layer instanceof io.intino.datahub.graph.Component) _component = (io.intino.datahub.graph.Component) layer;

		}

		public Create create() {
			return new Create(null);
		}

		public Create create(java.lang.String name) {
			return new Create(name);
		}

		public class Create  {
			protected final java.lang.String name;

			public Create(java.lang.String name) {
				this.name = name;
			}

			public io.intino.datahub.graph.Attribute attribute() {
			    io.intino.datahub.graph.Attribute newElement = core$().graph().concept(io.intino.datahub.graph.Attribute.class).createNode(this.name, core$()).as(io.intino.datahub.graph.Attribute.class);

			    return newElement;
			}

			public io.intino.datahub.graph.Component component() {
			    io.intino.datahub.graph.Component newElement = core$().graph().concept(io.intino.datahub.graph.Component.class).createNode(this.name, core$()).as(io.intino.datahub.graph.Component.class);

			    return newElement;
			}

			public io.intino.datahub.graph.Component.Has has(io.intino.datahub.graph.Component element) {
			    io.intino.datahub.graph.Component.Has newElement = core$().graph().concept(io.intino.datahub.graph.Component.Has.class).createNode(this.name, core$()).as(io.intino.datahub.graph.Component.Has.class);
				newElement.core$().set(newElement, "element", java.util.Collections.singletonList(element));
			    return newElement;
			}

		}

		public Clear clear() {
			return new Clear();
		}

		public class Clear  {
			public void attribute(java.util.function.Predicate<io.intino.datahub.graph.Attribute> filter) {
				new java.util.ArrayList<>(attributeList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
			}

			public void component(java.util.function.Predicate<io.intino.datahub.graph.Component> filter) {
				new java.util.ArrayList<>(componentList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
			}

			public void has(java.util.function.Predicate<io.intino.datahub.graph.Component.Has> filter) {
				new java.util.ArrayList<>(hasList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
			}
		}

		public io.intino.datahub.graph.NessGraph graph() {
			return (io.intino.datahub.graph.NessGraph) core$().graph().as(io.intino.datahub.graph.NessGraph.class);
		}
	}


	public io.intino.datahub.graph.NessGraph graph() {
		return (io.intino.datahub.graph.NessGraph) core$().graph().as(io.intino.datahub.graph.NessGraph.class);
	}
}

==> data-hub-5.2.0-sources.jar: io/intino/datahub/graph/Component.java <==
package io.intino.datahub.graph;

import io.intino.datahub.graph.*;

public class Component  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
	protected boolean multiple;
	protected java.util.List<io.intino.datahub.graph.Attribute> attributeList = new java.util.ArrayList<>();
	protected java.util.List<io.intino.datahub.graph.Component> componentList = new java.util.ArrayList<>();
	protected java.util.List<io.intino.datahub.graph.Component.Has> hasList = new java.util.ArrayList<>();
	protected io.intino.datahub.graph.Component.ExtensionOf _extensionOf;

	public Component(io.intino.magritte.framework.Node node) {
		super(node);
	}

	public boolean multiple() {
		return multiple;
	}

	public Component multiple(boolean value) {
		this.multiple = value;
		return (Component) this;
	}

	public java.util.List<io.intino.datahub.graph.Attribute> attributeList() {
		return java.util.Collections.unmodifiableList(attributeList);
	}

	public io.intino.datahub.graph.Attribute attribute(int index) {
		return attributeList.get(index);
	}

	public java.util.List<io.intino.datahub.graph.Attribute> attributeList(java.util.function.Predicate<io.intino.datahub.graph.Attribute> predicate) {
		return attributeList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}

	public io.intino.datahub.graph.Attribute attribute(java.util.function.Predicate<io.intino.datahub.graph.Attribute> predicate) {
		return attributeList().stream().filter(predicate).findFirst().orElse(null);
	}

	public java.util.List<io.intino.datahub.graph.Component> componentList() {
		return java.util.Collections.unmodifiableList(componentList);
	}

	public io.intino.datahub.graph.Component component(int index) {
		return componentList.get(index);
	}

	public java.util.List<io.intino.datahub.graph.Component> componentList(java.util.function.Predicate<io.intino.datahub.graph.Component> predicate) {
		return componentList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}

	public io.intino.datahub.graph.Component component(java.util.function.Predicate<io.intino.datahub.graph.Component> predicate) {
		return componentList().stream().filter(predicate).findFirst().orElse(null);
	}

	public java.util.List<io.intino.datahub.graph.Component.Has> hasList() {
		return java.util.Collections.unmodifiableList(hasList);
	}

	public io.intino.datahub.graph.Component.Has has(int index) {
		return hasList.get(index);
	}

	public java.util.List<io.intino.datahub.graph.Component.Has> hasList(java.util.function.Predicate<io.intino.datahub.graph.Component.Has> predicate) {
		return hasList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}

	public io.intino.datahub.graph.Component.Has has(java.util.function.Predicate<io.intino.datahub.graph.Component.Has> predicate) {
		return hasList().stream().filter(predicate).findFirst().orElse(null);
	}

	public io.intino.datahub.graph.Component.ExtensionOf asExtensionOf() {
		return a$(io.intino.datahub.graph.Component.ExtensionOf.class);
	}

	public io.intino.datahub.graph.Component.ExtensionOf asExtensionOf(io.intino.datahub.graph.Component parent) {
		io.intino.datahub.graph.Component.ExtensionOf newElement = core$().addAspect(io.intino.datahub.graph.Component.ExtensionOf.class);
		newElement.core$().set(newElement, "parent", java.util.Collections.singletonList(parent));
	    return newElement;
	}

	public boolean isExtensionOf() {
		return core$().is(io.intino.datahub.graph.Component.ExtensionOf.class);
	}

	public void removeExtensionOf() {
		core$().removeAspect(io.intino.datahub.graph.Component.ExtensionOf.class);
	}

	protected java.util.List<io.intino.magritte.framework.Node> componentList$() {
		java.util.Set<io.intino.magritte.framework.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(attributeList).forEach(c -> components.add(c.core$()));
		new java.util.ArrayList<>(componentList).forEach(c -> components.add(c.core$()));
		new java.util.ArrayList<>(hasList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
		map.put("multiple", new java.util.ArrayList(java.util.Collections.singletonList(this.multiple)));
		return map;
	}

	@Override
	protected void addNode$(io.intino.magritte.framework.Node node) {
		super.addNode$(node);
		if (node.is("Attribute")) this.attributeList.add(node.as(io.intino.datahub.graph.Attribute.class));
		if (node.is("Component")) this.componentList.add(node.as(io.intino.datahub.graph.Component.class));
		if (node.is("Component$Has")) this.hasList.add(node.as(io.intino.datahub.graph.Component.Has.class));
	}

	@Override
	    protected void removeNode$(io.intino.magritte.framework.Node node) {
	        super.removeNode$(node);
	        if (node.is("Attribute")) this.attributeList.remove(node.as(io.intino.datahub.graph.Attribute.class));
	        if (node.is("Component")) this.componentList.remove(node.as(io.intino.datahub.graph.Component.class));
	        if (node.is("Component$Has")) this.hasList.remove(node.as(io.intino.datahub.graph.Component.Has.class));
	    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
		if (name.equalsIgnoreCase("multiple")) this.multiple = io.intino.magritte.framework.loaders.BooleanLoader.load(values, this).get(0);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
		if (name.equalsIgnoreCase("multiple")) this.multiple = (java.lang.Boolean) values.get(0);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}

		public io.intino.datahub.graph.Attribute attribute() {
		    io.intino.datahub.graph.Attribute newElement = core$().graph().concept(io.intino.datahub.graph.Attribute.class).createNode(this.name, core$()).as(io.intino.datahub.graph.Attribute.class);

		    return newElement;
		}

		public io.intino.datahub.graph.Component component() {
		    io.intino.datahub.graph.Component newElement = core$().graph().concept(io.intino.datahub.graph.Component.class).createNode(this.name, core$()).as(io.intino.datahub.graph.Component.class);

		    return newElement;
		}

		public io.intino.datahub.graph.Component.Has has(io.intino.datahub.graph.Component element) {
		    io.intino.datahub.graph.Component.Has newElement = core$().graph().concept(io.intino.datahub.graph.Component.Has.class).createNode(this.name, core$()).as(io.intino.datahub.graph.Component.Has.class);
			newElement.core$().set(newElement, "element", java.util.Collections.singletonList(element));
		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void attribute(java.util.function.Predicate<io.intino.datahub.graph.Attribute> filter) {
			new java.util.ArrayList<>(attributeList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
		}

		public void component(java.util.function.Predicate<io.intino.datahub.graph.Component> filter) {
			new java.util.ArrayList<>(componentList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
		}

		public void has(java.util.function.Predicate<io.intino.datahub.graph.Component.Has> filter) {
			new java.util.ArrayList<>(hasList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
		}
	}

	public static class Has  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
		protected io.intino.datahub.graph.Component element;
		protected boolean multiple;

		public Has(io.intino.magritte.framework.Node node) {
			super(node);
		}

		public io.intino.datahub.graph.Component element() {
			return element;
		}

		public boolean multiple() {
			return multiple;
		}

		public Has element(io.intino.datahub.graph.Component value) {
			this.element = value;
			return (Has) this;
		}

		public Has multiple(boolean value) {
			this.multiple = value;
			return (Has) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("element", this.element != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.element)) : java.util.Collections.emptyList());
			map.put("multiple", new java.util.ArrayList(java.util.Collections.singletonList(this.multiple)));
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("element")) this.element = io.intino.magritte.framework.loaders.NodeLoader.load(values, io.intino.datahub.graph.Component.class, this).get(0);
			else if (name.equalsIgnoreCase("multiple")) this.multiple = io.intino.magritte.framework.loaders.BooleanLoader.load(values, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("element")) this.element = values.get(0)!= null ? core$().graph().load(((io.intino.magritte.framework.Layer) values.get(0)).core$().id()).as(io.intino.datahub.graph.Component.class) : null;
			else if (name.equalsIgnoreCase("multiple")) this.multiple = (java.lang.Boolean) values.get(0);
		}

		public io.intino.datahub.graph.NessGraph graph() {
			return (io.intino.datahub.graph.NessGraph) core$().graph().as(io.intino.datahub.graph.NessGraph.class);
		}
	}

	public static class ExtensionOf  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
		protected io.intino.datahub.graph.Component parent;
		protected io.intino.datahub.graph.Component _component;

		public ExtensionOf(io.intino.magritte.framework.Node node) {
			super(node);
		}

		public io.intino.datahub.graph.Component parent() {
			return parent;
		}

		public boolean multiple() {
			return _component.multiple();
		}

		public ExtensionOf parent(io.intino.datahub.graph.Component value) {
			this.parent = value;
			return (ExtensionOf) this;
		}

		public ExtensionOf multiple(boolean value) {
			this._component.multiple(value);
			return (ExtensionOf) this;
		}

		public java.util.List<io.intino.datahub.graph.Attribute> attributeList() {
			return (java.util.List<io.intino.datahub.graph.Attribute>) _component.attributeList();
		}

		public io.intino.datahub.graph.Attribute attributeList(int index) {
			return _component.attributeList().get(index);
		}

		public java.util.List<io.intino.datahub.graph.Component> componentList() {
			return (java.util.List<io.intino.datahub.graph.Component>) _component.componentList();
		}

		public io.intino.datahub.graph.Component componentList(int index) {
			return _component.componentList().get(index);
		}

		public java.util.List<io.intino.datahub.graph.Component.Has> hasList() {
			return (java.util.List<io.intino.datahub.graph.Component.Has>) _component.hasList();
		}

		public io.intino.datahub.graph.Component.Has hasList(int index) {
			return _component.hasList().get(index);
		}
		public io.intino.datahub.graph.Component asComponent() {
			return (io.intino.datahub.graph.Component) a$(io.intino.datahub.graph.Component.class);
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("parent", this.parent != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.parent)) : java.util.Collections.emptyList());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("parent")) this.parent = io.intino.magritte.framework.loaders.NodeLoader.load(values, io.intino.datahub.graph.Component.class, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("parent")) this.parent = values.get(0)!= null ? core$().graph().load(((io.intino.magritte.framework.Layer) values.get(0)).core$().id()).as(io.intino.datahub.graph.Component.class) : null;
		}

		@Override
		protected void sync$(io.intino.magritte.framework.Layer layer) {
			super.sync$(layer);
		    if (layer instanceof io.intino.datahub.graph.Component) _component = (io.intino.datahub.graph.Component) layer;

		}

		public Create create() {
			return new Create(null);
		}

		public Create create(java.lang.String name) {
			return new Create(name);
		}

		public class Create  {
			protected final java.lang.String name;

			public Create(java.lang.String name) {
				this.name = name;
			}

			public io.intino.datahub.graph.Attribute attribute() {
			    io.intino.datahub.graph.Attribute newElement = core$().graph().concept(io.intino.datahub.graph.Attribute.class).createNode(this.name, core$()).as(io.intino.datahub.graph.Attribute.class);

			    return newElement;
			}

			public io.intino.datahub.graph.Component component() {
			    io.intino.datahub.graph.Component newElement = core$().graph().concept(io.intino.datahub.graph.Component.class).createNode(this.name, core$()).as(io.intino.datahub.graph.Component.class);

			    return newElement;
			}

			public io.intino.datahub.graph.Component.Has has(io.intino.datahub.graph.Component element) {
			    io.intino.datahub.graph.Component.Has newElement = core$().graph().concept(io.intino.datahub.graph.Component.Has.class).createNode(this.name, core$()).as(io.intino.datahub.graph.Component.Has.class);
				newElement.core$().set(newElement, "element", java.util.Collections.singletonList(element));
			    return newElement;
			}

		}

		public Clear clear() {
			return new Clear();
		}

		public class Clear  {
			public void attribute(java.util.function.Predicate<io.intino.datahub.graph.Attribute> filter) {
				new java.util.ArrayList<>(attributeList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
			}

			public void component(java.util.function.Predicate<io.intino.datahub.graph.Component> filter) {
				new java.util.ArrayList<>(componentList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
			}

			public void has(java.util.function.Predicate<io.intino.datahub.graph.Component.Has> filter) {
				new java.util.ArrayList<>(hasList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
			}
		}

		public io.intino.datahub.graph.NessGraph graph() {
			return (io.intino.datahub.graph.NessGraph) core$().graph().as(io.intino.datahub.graph.NessGraph.class);
		}
	}


	public io.intino.datahub.graph.NessGraph graph() {
		return (io.intino.datahub.graph.NessGraph) core$().graph().as(io.intino.datahub.graph.NessGraph.class);
	}
}
